@@ -13,10 +13,13 @@
 #endif
 #endif
 
+extern int RC_WAVE_ALLOW_GTK3_HEADER_BAR;
+
 #if GTK_CHECK_VERSION(3,0,0)
 
 #ifndef MAC_INTEGRATION
-#define WAVE_ALLOW_GTK3_HEADER_BAR
+// #define WAVE_ALLOW_GTK3_HEADER_BAR
+#define XXX_WAVE_ALLOW_GTK3_HEADER_BAR
 #endif
 
 /* workaround for wave_vslider not rendering properly on startup */
