@@ -54,7 +54,7 @@
 
 static uint32_t var_direction_idx = 0;
 static unsigned char *var_direction = NULL;
-
+static int mti_realparam_fix = 0;
 
 static void *realloc_2(void *ptr, size_t siz) /* cppcheck */
 {
@@ -70,14 +70,23 @@ return(pnt);
 
 /******************************************************/
 
-static FILE *popen_san(const char *command, const char *type) /* TALOS-2023-1786 */
+static FILE *popen_san(const char *command, const char *type, int fsdb_suffix_security_override) /* TALOS-2023-1786 */
 {
 const char *p = command;
 int is_ok = 1;
 char ch;
+int len = command ? strlen(command) : 0;
+const char *mp = NULL;
+
+if(fsdb_suffix_security_override && (len > 5) && !strcmp(" 2>&1", p+len-5))
+	{
+	mp = p+len-5;
+	}
 
 while(p && (ch = *(p++)))
 	{
+	if(p == mp) break; /* ensure fsdb filters can run */
+
 	switch(ch)
 		{
 		case '&':
@@ -318,7 +327,7 @@ FILE *extload;
 void *xc = fstReaderOpenForUtilitiesOnly();
 
 sprintf(sbuff, "%s -info %s 2>&1", EXTLOAD_PATH, fname);
-extload = popen_san(sbuff, "r");
+extload = popen_san(sbuff, "r", 1);
 if(extload)
 	{
 	while(get_info(extload));
@@ -332,7 +341,7 @@ if(numfacs)
 	}
 
 sprintf(sbuff, "%s -tree %s 2>&1", EXTLOAD_PATH, fname);
-extload = popen_san(sbuff, "r");
+extload = popen_san(sbuff, "r", 1);
 if(extload)
 	{
 	while(get_scopename(xc, extload));
@@ -452,6 +461,7 @@ if((!(*buf)[0])||(!fgets_rc))
 }
 
 JRB vcd_ids = NULL;
+JRB zerolen_ids = NULL; /* github #446 */
 
 static unsigned int vcdid_hash(char *s, int len)
 {
@@ -519,7 +529,7 @@ if(!strcmp("-", vname))
 	if(suffix_check(vname, "."EXTLOAD_SUFFIX) || suffix_check(vname, "."EXTLOAD_SUFFIX".gz") || suffix_check(vname, "."EXTLOAD_SUFFIX".bz2"))
 		{
 		sprintf(bin_fixbuff, EXTCONV_PATH" %s", vname);
-		f = popen_san(bin_fixbuff, "r");
+		f = popen_san(bin_fixbuff, "r", 0);
 		is_popen = 1;
 		is_extload = 1;
 #ifndef _WAVE_HAVE_JUDY
@@ -534,7 +544,7 @@ if(!strcmp("-", vname))
 		if(suffix_check(vname, "."EXT2LOAD_SUFFIX))
 			{
 			sprintf(bin_fixbuff, EXT2CONV_PATH" %s", vname);
-			f = popen_san(bin_fixbuff, "r");
+			f = popen_san(bin_fixbuff, "r", 0);
 			is_popen = 1;
 			}
 			else
@@ -543,7 +553,7 @@ if(!strcmp("-", vname))
 		if(suffix_check(vname, "."EXT3LOAD_SUFFIX))
 			{
 			sprintf(bin_fixbuff, EXT3CONV_PATH" %s", vname);
-			f = popen_san(bin_fixbuff, "r");
+			f = popen_san(bin_fixbuff, "r", 0);
 			is_popen = 1;
 			}
 			else
@@ -581,6 +591,7 @@ if(is_popen && is_extload)
 #endif
 
 vcd_ids = make_jrb();
+zerolen_ids = make_jrb(); /* github #446 */
 fstWriterSetPackType(ctx, pack_type);
 fstWriterSetRepackOnClose(ctx, repack_all);
 fstWriterSetParallelMode(ctx, parallel_mode);
@@ -603,6 +614,7 @@ while(!feof(f))
 		{
 		char *st = strtok(buf+5, " \t");
 		enum fstVarType vartype;
+		int zerolen = 0;
 		int len;
 		char *nam;
 		unsigned int hash;
@@ -817,7 +829,18 @@ while(!feof(f))
 			case FST_VT_GEN_STRING: len = 0; break;
 			case FST_VT_VCD_EVENT: len = (len != 0) ? len : 1;  break;
 			default:
-				if(len == 0) { len = 1; }
+				if(len == 0) 
+					{ 
+					len = 1; 
+					if((mti_realparam_fix) && (vartype == FST_VT_VCD_PARAMETER))
+						{
+						vartype = FST_VT_VCD_REAL_PARAMETER;
+						}
+					else
+						{
+						zerolen = (vartype != FST_VT_VCD_REAL) && (vartype != FST_VT_VCD_REAL_PARAMETER) && (vartype != FST_VT_VCD_REALTIME) && (vartype != FST_VT_SV_SHORTREAL);
+						}
+					}
 				break;
 			}
 
@@ -861,6 +884,18 @@ while(!feof(f))
 				fstWriterCreateVar(ctx, vartype, !var_direction ? FST_VD_IMPLICIT : var_direction[var_direction_idx++], node->val2.i, nam, node->val.i);
 				}
 
+			if(zerolen) /* github #446 */
+				{
+				node = jrb_find_int(zerolen_ids, hash);
+				if(!node)
+					{
+					/* fprintf(stderr, "VCD2FST | Name '%s'\n", nam); */
+					Jval val;
+					val.i = vartype;
+					jrb_insert_int(zerolen_ids, hash, val)->val2.i = 0;
+					}
+				}
+
 #if defined(VCD2FST_EXTLOAD_CONV)
 			if(var_direction)
 				{
@@ -1297,6 +1332,10 @@ while(!feof(f))
 
 		if(is_version)
 			{
+			if(strstr(pnt, "Questa") || strstr(pnt, "ModelSim")) /* realparam fix only is for MTI, conflicts with Vivado */
+				{
+				mti_realparam_fix = 1;
+				}
 			fstWriterSetVersion(ctx, pnt);
 			}
 			else
@@ -1333,6 +1372,12 @@ if((!hash_kill) && (vcd_ids))
 	hash_kill = 1; /* scan-build */
 	}
 
+if(jrb_empty(zerolen_ids)) /* github #446 */
+	{
+	jrb_free_tree(zerolen_ids);
+	zerolen_ids = NULL;
+	}
+
 for(;;) /* was while(!feof(f)) */
 	{
 	unsigned int hash;
@@ -1545,6 +1590,19 @@ for(;;) /* was while(!feof(f)) */
 			sp = strchr(buf, ' ');
 			if(!sp) break;
 			hash = vcdid_hash(sp+1, nl - (sp+1));
+
+                        if(zerolen_ids) /* github #446 */
+                                {
+                                node = jrb_find_int(zerolen_ids, hash);
+                                if(node)
+                                        {
+					char *hash_str = strndup(sp+1, nl - (sp+1));
+                                        fprintf(stderr, "VCD2FST | Warning: write of real value change to nonreal VCD ID %s suppressed.\n", hash_str); /* github #446, Vivado emitting both boolean and real ambiguously to a zero length parameter */
+					free(hash_str);
+					break;
+                                        }
+                                }
+
 			if(!hash_kill)
 				{
 		                sscanf(buf+1,"%lg",&doub);
@@ -1635,6 +1693,12 @@ if(vcd_ids)
 	vcd_ids = NULL;
 	}
 
+if(zerolen_ids) /* github #446 */
+	{
+	jrb_free_tree(zerolen_ids);
+	zerolen_ids = NULL;
+	}
+
 free(bin_fixbuff); bin_fixbuff = NULL;
 free(wbuf); wbuf = NULL;
 free(node_len_array); node_len_array = NULL;
